.. _api:

API reference
-------------

This page provides an auto-generated summary of Xbatcher's API.

Core
====

.. currentmodule:: xbatcher

.. autosummary::
   :toctree: generated/

   BatchGenerator
   BatchSchema

Xbatcher Xarray accessors
=========================

.. currentmodule:: xarray

.. autosummary::
   :toctree: generated/
   :template: autosummary/accessor_method.rst

   Dataset.batch.generator
   DataArray.batch.generator

Dataloaders
===========

.. currentmodule:: xbatcher

.. autosummary::
   :toctree: generated/

   loaders.torch.MapDataset
   loaders.torch.IterableDataset
   loaders.keras.CustomTFDataset
   :members:
